@@ -1,3 +1,6 @@
+c      https://stackoverflow.com/questions/3170239/fortran-integer4-vs-integer4-vs-integerkind-4
+
+
       subroutine get_f(input, index, output)
       double precision :: input(*), output(*)
       integer :: index
@@ -6,7 +9,7 @@
 
       subroutine get64_f(input, index, output)
       double precision :: input(*), output(*)
-      integer (kind = 8) :: index  ! 64-bit integer on GFortran, differs with other compilers   
+      integer (8) :: index  ! 64-bit integer on GFortran, differs with other compilers   
       output(1) = input(index)
       end
 
